==> qtjambi-quick-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiQuick/QSGOpenGLTexture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(opengl)



#endif // QT_CONFIG(opengl)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGOpenGLTexture::nativeTexture()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGOpenGLTexture_00024Impl_00024ConcreteWrapper_nativeTexture_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(opengl)
        const QNativeInterface::QSGOpenGLTexture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGOpenGLTexture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGOpenGLTexture::nativeTexture()const", __qt_this)
        GLuint __qt_return_value = __qt_this->nativeTexture();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(opengl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGOpenGLTexture::fromNative(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGOpenGLTexture_00024Impl_fromNative_1native_1GLuint_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__IJJI)
(JNIEnv *__jni_env,
 jclass,
 jint textureId0,
 QtJambiNativeID window1,
 QtJambiNativeID size2,
 jint options3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGOpenGLTexture::fromNative(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(opengl)
        QQuickWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window1);
        const QSize& __qt_size2 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size2);
        QQuickWindow::CreateTextureOptions __qt_options3 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options3);
        QSGTexture* __qt_return_value = QNativeInterface::QSGOpenGLTexture::fromNative(static_cast<GLuint>(textureId0), __qt_window1, __qt_size2, QQuickWindow::CreateTextureOptions(__qt_options3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(textureId0)
        Q_UNUSED(window1)
        Q_UNUSED(size2)
        Q_UNUSED(options3)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(opengl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGOpenGLTexture::fromNativeExternalOES(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGOpenGLTexture_00024Impl_fromNativeExternalOES_1native_1GLuint_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__IJJI)
(JNIEnv *__jni_env,
 jclass,
 jint textureId0,
 QtJambiNativeID window1,
 QtJambiNativeID size2,
 jint options3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGOpenGLTexture::fromNativeExternalOES(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(opengl)
        QQuickWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window1);
        const QSize& __qt_size2 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size2);
        QQuickWindow::CreateTextureOptions __qt_options3 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options3);
        QSGTexture* __qt_return_value = QNativeInterface::QSGOpenGLTexture::fromNativeExternalOES(static_cast<GLuint>(textureId0), __qt_window1, __qt_size2, QQuickWindow::CreateTextureOptions(__qt_options3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(textureId0)
        Q_UNUSED(window1)
        Q_UNUSED(size2)
        Q_UNUSED(options3)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(opengl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGOpenGLTexture(){
    using namespace RegistryAPI;

#if QT_CONFIG(opengl)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGOpenGLTexture>("QNativeInterface::QSGOpenGLTexture", "io/qt/quick/nativeinterface/QSGOpenGLTexture");
    registerNativeInterface<QNativeInterface::QSGOpenGLTexture>("io/qt/quick/nativeinterface/QSGOpenGLTexture");
// BEGIN: function table
    registerConstructorInfos(typeId, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGOpenGLTexture* _object = dynamic_cast<QNativeInterface::QSGOpenGLTexture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGOpenGLTexture *object = reinterpret_cast<QNativeInterface::QSGOpenGLTexture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGOpenGLTexture *object = reinterpret_cast<const QNativeInterface::QSGOpenGLTexture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(opengl)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGOpenGLTexture", {});

#endif //QT_CONFIG(opengl)

}

==> qtjambi-quick-debuginfo-linux-x64-6.7.2.jar: sources/QtJambiQuick/QSGOpenGLTexture_shell.cpp <==
#include <QtCore/QtGlobal>
#if __has_include(<QtQuick/qsgtexture_platform.h>)
#include <QtQuick/qsgtexture_platform.h>
#endif
#include <QtCore/QVariant>
#include <QtCore/qsize.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgtexture.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/CoreAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

#if QT_CONFIG(opengl)



#endif // QT_CONFIG(opengl)

// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QNativeInterface::QSGOpenGLTexture::nativeTexture()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGOpenGLTexture_00024Impl_00024ConcreteWrapper_nativeTexture_1native_1constfct__J)
(JNIEnv *__jni_env,
 jclass,
 QtJambiNativeID __this_nativeId)
{
    jint __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(opengl)
        const QNativeInterface::QSGOpenGLTexture *__qt_this = QtJambiAPI::interfaceFromNativeId<QNativeInterface::QSGOpenGLTexture>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNativeInterface::QSGOpenGLTexture::nativeTexture()const", __this_nativeId)
        GLuint __qt_return_value = __qt_this->nativeTexture();
        __java_return_value = jint(__qt_return_value);
#else
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(opengl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGOpenGLTexture::fromNative(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGOpenGLTexture_00024Impl_fromNative_1native_1GLuint_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__IJJI)
(JNIEnv *__jni_env,
 jclass,
 jint textureId0,
 QtJambiNativeID window1,
 QtJambiNativeID size2,
 jint options3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGOpenGLTexture::fromNative(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(opengl)
        QQuickWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window1);
        const QSize& __qt_size2 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size2);
        QQuickWindow::CreateTextureOptions __qt_options3 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options3);
        QSGTexture* __qt_return_value = QNativeInterface::QSGOpenGLTexture::fromNative(static_cast<GLuint>(textureId0), __qt_window1, __qt_size2, QQuickWindow::CreateTextureOptions(__qt_options3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(textureId0)
        Q_UNUSED(window1)
        Q_UNUSED(size2)
        Q_UNUSED(options3)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(opengl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNativeInterface::QSGOpenGLTexture::fromNativeExternalOES(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_quick_nativeinterface_QSGOpenGLTexture_00024Impl_fromNativeExternalOES_1native_1GLuint_1QQuickWindow_1ptr_1cref_1QSize_1QQuickWindow_1CreateTextureOptions__IJJI)
(JNIEnv *__jni_env,
 jclass,
 jint textureId0,
 QtJambiNativeID window1,
 QtJambiNativeID size2,
 jint options3)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNativeInterface::QSGOpenGLTexture::fromNativeExternalOES(GLuint,QQuickWindow*,QSize,QQuickWindow::CreateTextureOptions)")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(opengl)
        QQuickWindow* __qt_window1 = QtJambiAPI::objectFromNativeId<QQuickWindow>(window1);
        const QSize& __qt_size2 = QtJambiAPI::valueReferenceFromNativeId<QSize>(size2);
        QQuickWindow::CreateTextureOptions __qt_options3 = qtjambi_cast<QQuickWindow::CreateTextureOptions>(__jni_env, options3);
        QSGTexture* __qt_return_value = QNativeInterface::QSGOpenGLTexture::fromNativeExternalOES(static_cast<GLuint>(textureId0), __qt_window1, __qt_size2, QQuickWindow::CreateTextureOptions(__qt_options3));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnershipForTopLevelObject(__jni_env, __qt_return_value);
#else
        Q_UNUSED(textureId0)
        Q_UNUSED(window1)
        Q_UNUSED(size2)
        Q_UNUSED(options3)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(opengl)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QNativeInterface_QSGOpenGLTexture(){
    using namespace RegistryAPI;

#if QT_CONFIG(opengl)

    const std::type_info& typeId = registerInterfaceTypeInfo<QNativeInterface::QSGOpenGLTexture>("QNativeInterface::QSGOpenGLTexture", "io/qt/quick/nativeinterface/QSGOpenGLTexture");
    registerNativeInterface<QNativeInterface::QSGOpenGLTexture>("io/qt/quick/nativeinterface/QSGOpenGLTexture");
// BEGIN: function table
    registerConstructorInfos(typeId, 0, nullptr, {
    });
// END: function table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
    registerPolymorphyHandler(typeid(QObject), typeId, [](void *ptr, qintptr& offset) -> bool {
            QObject *object = reinterpret_cast<QObject *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QNativeInterface::QSGOpenGLTexture* _object = dynamic_cast<QNativeInterface::QSGOpenGLTexture*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerPolymorphyHandler(typeId, typeid(QObject), [](void *ptr, qintptr& offset) -> bool {
            QNativeInterface::QSGOpenGLTexture *object = reinterpret_cast<QNativeInterface::QSGOpenGLTexture *>(ptr);
            Q_ASSERT(object);
            bool _result = false;
            QTJAMBI_TRY_ANY {
                if(QObject* _object = dynamic_cast<QObject*>(object)){
                    offset = qintptr(object)-qintptr(_object);
                    _result = true;
                }
            } QTJAMBI_CATCH_ANY{
            } QTJAMBI_TRY_END
            return _result;
        });
    registerOwnerFunction(typeId, [](const void *ptr)->const QObject*{
        const QNativeInterface::QSGOpenGLTexture *object = reinterpret_cast<const QNativeInterface::QSGOpenGLTexture *>(ptr);
        const QObject* _result = nullptr;
        QTJAMBI_TRY_ANY {
            _result = dynamic_cast<const QObject*>(object);
        } QTJAMBI_CATCH_ANY{
        } QTJAMBI_TRY_END
        return _result;
    });
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#else //QT_CONFIG(opengl)

    registerNativeInterface("io/qt/quick/nativeinterface/QSGOpenGLTexture", {});

#endif //QT_CONFIG(opengl)

}
